@@ -1,5 +1,6 @@
 import collections
 import configparser
+import inspect
 import itertools
 import logging
 import os
@@ -203,10 +204,17 @@ class Client(collections.abc.Mapping):
         # If specified by a string
         if device_cls in containers.registry:
             device_cls = containers.registry[device_cls]
+
         # Check that this is a valid HappiItem
-        if not issubclass(device_cls, HappiItem):
-            raise TypeError('{!r} is not a subclass of '
-                            'HappiItem'.format(device_cls))
+        if isinstance(device_cls, str):
+            raise TypeError(
+                f'The device class {device_cls!r} is not in the registry'
+            )
+
+        if (not inspect.isclass(device_cls) or
+                not issubclass(device_cls, HappiItem)):
+            raise TypeError(f'{device_cls!r} is not a subclass of HappiItem')
+
         device = device_cls(**kwargs)
         # Add the method to the device
 
@@ -378,8 +386,15 @@ class Client(collections.abc.Mapping):
         Return search results to the user, optionally wrapping with a class
         '''
         wrap_cls = wrap_cls or self._results_wrap_class
-        return [wrap_cls(client=self, device=self.find_device(**info))
-                for info in items]
+        results = []
+        for info in items:
+            try:
+                result = wrap_cls(client=self, device=self.find_device(**info))
+                results.append(result)
+            except Exception as exc:
+                logger.warning('Entry for %s is malformed (%s). Skipping.',
+                               info['name'], exc)
+        return results
 
     def search_range(self, key, start, end=None, **kwargs):
         """
@@ -569,6 +584,9 @@ class Client(collections.abc.Mapping):
         self._validate_device(device)
         # Grab information from device
         post = device.post()
+        # save the old name in case the user is trying to
+        # change the 'name' of an entry
+        the_old_name = post.get('_id', None)
         # Store creation time
         creation = post.get('creation', ttime.ctime())
         # Clean supplied information
@@ -585,6 +603,7 @@ class Client(collections.abc.Mapping):
         post.update({'type': tpe,
                      'creation': creation,
                      'last_edit': ttime.ctime()})
+
         # Find id
         try:
             _id = post[self._id_key]
@@ -592,9 +611,19 @@ class Client(collections.abc.Mapping):
             raise EntryError('HappiItem did not supply the proper information '
                              'to interface with the database, missing {}'
                              ''.format(self._id_key))
-        # Store information
-        logger.info('Adding / Modifying information for %s ...', _id)
-        self.backend.save(_id, post, insert=insert)
+        # In case we want to update the name of an entry
+        # We want to add a new entry, and delete the old one
+        if the_old_name and the_old_name != post[self._id_key]:
+            # Store information for the new entry
+            logger.info('Saving new entry %s ...', _id)
+            self.backend.save(_id, post, insert=True)
+            # Remove the information for the old entry
+            logger.info('Removing old entry %s ...', the_old_name)
+            self.backend.delete(the_old_name)
+        else:
+            # Store information
+            logger.info('Adding / Modifying information for %s ...', _id)
+            self.backend.save(_id, post, insert=insert)
         return _id
 
     @classmethod
